@@ -19,19 +19,15 @@ from tornado import web
 from .filecheckpoints import AsyncFileCheckpoints, FileCheckpoints
 from .fileio import AsyncFileManagerMixin, FileManagerMixin
 from .manager import AsyncContentsManager, ContentsManager
-from ...utils import exists
 
 from ipython_genutils.importstring import import_item
 from traitlets import Any, Unicode, Bool, TraitError, observe, default, validate
 from ipython_genutils.py3compat import getcwd, string_types
 
+from jupyter_core.paths import exists, is_hidden, is_file_hidden
 from jupyter_server import _tz as tz
-from jupyter_server.utils import (
-    is_hidden, is_file_hidden,
-    to_api_path,
-)
 from jupyter_server.base.handlers import AuthenticatedFileHandler
-from jupyter_server.transutils import _
+from jupyter_server.transutils import _i18n
 
 try:
     from os.path import samefile
@@ -535,7 +531,7 @@ class FileContentsManager(FileManagerMixin, ContentsManager):
                                 (old_path, e)) from e
 
     def info_string(self):
-        return _("Serving notebooks from local directory: %s") % self.root_dir
+        return _i18n("Serving notebooks from local directory: %s") % self.root_dir
 
     def get_kernel_path(self, path, model=None):
         """Return the initial API path of  a kernel associated with a given notebook"""
@@ -844,4 +840,4 @@ class AsyncFileContentsManager(FileContentsManager, AsyncFileManagerMixin, Async
             raise
         except Exception as e:
             raise web.HTTPError(500, u'Unknown error renaming file: %s %s' %
-                                (old_path, e)) from e
\ No newline at end of file
+                                (old_path, e)) from e
